@@ -12,22 +12,19 @@ class Cache(object):
     def read(self) -> dict:
         return json.loads(self.contents)
 
-class LocalCache(object):
+class LocalCache(Cache):
     def __init__(self, path: str) -> None:
         self.path = path
 
     def write(self, data) -> None:
         with open(self.path, 'w') as output:
-            output.write(
-              json.dumps(data)
-            )
+            output.write(json.dumps(data))
 
     def read(self):
         if not os.path.exists(self.path):
             return {}
 
-        contents = ''
         with open(self.path, 'r') as input:
-            contents = input.read()
+            data = json.loads(input.read())
 
-        return json.loads(contents)
+        return data
